import logging
import logging.config


main_logger = logging.getLogger("main")
notetype_logger = logging.getLogger("notetype")
parser_logger = logging.getLogger("parser")
helper_logger = logging.getLogger("helper")
